# Materials for students in Peking University HSBC Business School 
=====================================

Import packages:
`from phbs import jakezhao`

Homework Answer:
`jakezhao.hw1()` (you can also change to hw1~hw4) provides you the relative homework answer.